#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework
version:              0.8.2.3
visibility:           public
id:                   test-framework-0.8.2.3-6OIA6eLdAHe8BnWI3puann
key:                  test-framework-0.8.2.3-6OIA6eLdAHe8BnWI3puann
license:              BSD-3-Clause
maintainer:           Andreas Abel
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://github.com/haskell/test-framework#readme
synopsis:
    Framework for running and organising tests, with HUnit and QuickCheck support

description:
    Allows tests such as QuickCheck properties and HUnit test cases to be assembled into test groups, run in
    parallel (but reported in deterministic order, to aid diff interpretation) and filtered and controlled by
    command line options. All of this comes with colored test output, progress reporting and test statistics output.

category:             Testing
abi:                  8245c61943f0fd5551597748f23c1132
exposed:              True
exposed-modules:
    Test.Framework Test.Framework.Options Test.Framework.Providers.API
    Test.Framework.Runners.API Test.Framework.Runners.Console
    Test.Framework.Runners.Options Test.Framework.Runners.TestPattern
    Test.Framework.Seed

hidden-modules:
    Test.Framework.Core Test.Framework.Improving
    Test.Framework.Runners.Console.Colors
    Test.Framework.Runners.Console.ProgressBar
    Test.Framework.Runners.Console.Run
    Test.Framework.Runners.Console.Statistics
    Test.Framework.Runners.Console.Table
    Test.Framework.Runners.Console.Utilities
    Test.Framework.Runners.Core Test.Framework.Runners.Processors
    Test.Framework.Runners.Statistics Test.Framework.Runners.ThreadPool
    Test.Framework.Runners.TimedConsumption
    Test.Framework.Runners.XML.JUnitWriter Test.Framework.Runners.XML
    Test.Framework.Utilities

import-dirs:          /usr/lib/ghc-9.6.6/site-local/test-framework-0.8.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/test-framework-0.8.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/test-framework-0.8.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework
hs-libraries:         HStest-framework-0.8.2.3-6OIA6eLdAHe8BnWI3puann
depends:
    ansi-terminal-1.1-JoJLZTsqfbj9DJv1N5mqCP
    ansi-wl-pprint-1.0.2-689Qq5UOTwU4qvzG5P1gJ3 base-4.18.2.1
    containers-0.6.7 hostname-1.0-EOhxbdAArOFEFh3i6bjNP6
    random-1.2.1.3-5RWjRNGMcAI4pn7QxDBoxf
    regex-posix-0.96.0.2-LsCmj8tXKerCmkZ6TKO5qF time-1.12.2
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt

haddock-interfaces:
    /usr/share/doc/haskell-test-framework/html/test-framework.haddock

haddock-html:         /usr/share/doc/haskell-test-framework/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

